==> abiword-1.0.4.tar.bz2: abiword-1.0.4/MSVC6/PCH_wpap.h <==
#define NOSERVICE
#include <windows.h>
#include <commctrl.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
#include <time.h>
#include <sys/types.h>
#include <sys/stat.h>

#include "ut_types.h"
#include "ut_assert.h"
#include "ut_string.h"
#include "ut_stack.h"
#include "ut_debugmsg.h"
#include "ut_growbuf.h"
#include "ut_misc.h"
#include "ut_vector.h"
#include "ut_xml.h"

#include "ut_Win32OS.h"

#include "fp_Run.h"
#include "fv_View.h"
#include "pd_Document.h"
#include "pl_Listener.h"

#include "xap_App.h"
#include "xap_Args.h"
#include "xap_EditMethods.h"
#include "xap_EncodingManager.h"
#include "xap_Menu_ActionSet.h"
#include "xap_Prefs.h"
#include "xap_Toolbar_ActionSet.h"
#include "xap_Types.h"
#include "xap_Win32App.h"
#include "xap_Win32Frame.h"

#include "ap_Clipboard.h"
#include "ap_Convert.h"
#include "ap_EditMethods.h"
#include "ap_Dialog_Id.h"
#include "ap_Dialog_Field.h"
#include "ap_LoadBindings.h"
#include "ap_Prefs_SchemeIds.h"
#include "ap_Strings.h"
#include "ap_Win32App.h"
#include "ap_Win32Resources.rc2"
#include "xap_Win32Dlg_MessageBox.h"
#include "xap_Win32Dlg_FileOpenSaveAs.h"
#include "xap_Win32Dlg_Print.h"
#include "xap_Win32Dlg_FontChooser.h"
#include "xap_Win32Dlg_WindowMore.h"
#include "xap_Win32Dlg_About.h"
#include "xap_Win32Dlg_Zoom.h"
#include "xap_Win32Dlg_Insert_Symbol.h"
#include "xap_Win32Dlg_Language.h"
#include "xap_Win32Dlg_Encoding.h"
#include "ap_Win32Dialog_Replace.h"
#include "ap_Win32Dialog_Break.h"
#include "ap_Win32Dialog_Options.h"
#include "ap_Win32Dialog_Paragraph.h"
#include "ap_Win32Dialog_Spell.h"
#include "ap_Win32Dialog_Styles.h"
#include "ap_Win32Dialog_Insert_DateTime.h"
#include "ap_Win32Dialog_WordCount.h"
#include "ap_Win32Dialog_Field.h"
#include "ap_Win32Dialog_Goto.h"
#include "ap_Win32Dialog_Columns.h"
#include "ap_Win32Dialog_Lists.h"
#include "ap_Win32Dialog_Tab.h"
#include "ap_Win32Dialog_PageNumbers.h"
#include "ap_Win32Dialog_PageSetup.h"
#include "ap_Win32Dialog_ToggleCase.h"
#include "ap_Win32Dialog_Background.h"
#include "ap_Win32Dialog_New.h"
#include "ap_Win32Frame.h"

==> abiword-2.4.5.tar.bz2: abiword-2.4.5/MSVC6/PCH_wpap.h <==
#define NOSERVICE
#include <windows.h>
#include <commctrl.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
#include <time.h>
#include <sys/types.h>
#include <sys/stat.h>

#include "ut_types.h"
#include "ut_assert.h"
#include "ut_string.h"
#include "ut_stack.h"
#include "ut_debugmsg.h"
#include "ut_growbuf.h"
#include "ut_misc.h"
#include "ut_vector.h"
#include "ut_xml.h"

#include "ut_Win32OS.h"

#include "fp_Run.h"
#include "fv_View.h"
#include "pd_Document.h"
#include "pl_Listener.h"

#include "xap_App.h"
#include "xap_Args.h"
#include "xap_EditMethods.h"
#include "xap_EncodingManager.h"
#include "xap_Menu_ActionSet.h"
#include "xap_Prefs.h"
#include "xap_Toolbar_ActionSet.h"
#include "xap_Types.h"
#include "xap_Win32App.h"
#include "xap_Win32FrameImpl.h"

#include "ap_Clipboard.h"
#include "ap_Convert.h"
#include "ap_EditMethods.h"
#include "ap_Dialog_Id.h"
#include "ap_Dialog_Field.h"
#include "ap_LoadBindings.h"
#include "ap_Prefs_SchemeIds.h"
#include "ap_Strings.h"
#include "ap_Win32App.h"
#include "ap_Win32Resources.rc2"
#include "xap_Win32Dlg_MessageBox.h"
#include "xap_Win32Dlg_FileOpenSaveAs.h"
#include "xap_Win32Dlg_Print.h"
#include "xap_Win32Dlg_FontChooser.h"
#include "xap_Win32Dlg_WindowMore.h"
#include "xap_Win32Dlg_About.h"
#include "xap_Win32Dlg_Zoom.h"
#include "xap_Win32Dlg_Insert_Symbol.h"
#include "xap_Win32Dlg_Language.h"
#include "xap_Win32Dlg_Encoding.h"
#include "ap_Win32Dialog_Replace.h"
#include "ap_Win32Dialog_Break.h"
#include "ap_Win32Dialog_Options.h"
#include "ap_Win32Dialog_Paragraph.h"
#include "ap_Win32Dialog_Spell.h"
#include "ap_Win32Dialog_Styles.h"
#include "ap_Win32Dialog_Insert_DateTime.h"
#include "ap_Win32Dialog_WordCount.h"
#include "ap_Win32Dialog_Field.h"
#include "ap_Win32Dialog_Goto.h"
#include "ap_Win32Dialog_Columns.h"
#include "ap_Win32Dialog_Lists.h"
#include "ap_Win32Dialog_Tab.h"
#include "ap_Win32Dialog_PageNumbers.h"
#include "ap_Win32Dialog_PageSetup.h"
#include "ap_Win32Dialog_ToggleCase.h"
#include "ap_Win32Dialog_Background.h"
#include "ap_Win32Dialog_New.h"
#include "ap_Win32Frame.h"
